As a work of the United States Government, this package (excluding the
exceptions below) is in the public domain within the United States.
Additionally, we waive copyright and related rights in the work worldwide
through the CC0 1.0 Universal public domain dedication.

Software source code previously released under an open source license and then
modified by CFPB staff is considered a "joint work" (see 17 USC § 101); it is
partially copyrighted, partially public domain, and as a whole is protected by
the copyrights of the non-government authors and must be released according to
the terms of the original open-source license.

For further details, please see the CFPB [Source Code Policy][policy].


## CC0 1.0 Universal Summary

This is a human-readable summary of the [Legal Code (read the full text)][CC0].

### No Copyright

The person who associated a work with this deed has dedicated the work to
the public domain by waiving all of his or her rights to the work worldwide
under copyright law, including all related and neighboring rights, to the
extent allowed by law.

You can copy, modify, distribute and perform the work, even for commercial 
purposes, all without asking permission. See Other Information below.

### Other Information

In no way are the patent or trademark rights of any person affected by CC0,
nor are the rights that other persons may have in the work or in how the
work is used, such as publicity or privacy rights.

Unless expressly stated otherwise, the person who associated a work with
this deed makes no warranties about the work, and disclaims liability for
all uses of the work, to the fullest extent permitted by applicable law.
When using or citing the work, you should not imply endorsement by the
author or the affirmer.

[policy]: http://github.com/cfpb/source-code-policy/
[CC0]: http://creativecommons.org/publicdomain/zero/1.0/legalcode

